==> eclipse-pydev_1.0.3.orig.tar.gz: eclipse-pydev-1.0.3/org.python.pydev.debug/src/org/python/pydev/debug/core/Constants.java <==
/*
 * Author: atotic
 * Created: Aug 20, 2003
 * License: Common Public License v1.0
 */
package org.python.pydev.debug.core;

/**
 * all the public constants for pydev.debug
 */
public interface Constants {

	// Icons
	static final String MAIN_ICON = "icons/python.gif";
	
	// Plugin constants
	static final String PLUGIN_ID = "org.python.pydev.debug";
	static final String PYTHON_DEBUG_LAUNCH_GROUP = "org.python.pydev.debug.debug";
	static final String PYTHON_RUN_LAUNCH_GROUP = "org.python.pydev.debug.run";
	static final String PYTHON_COVERAGE_LAUNCH_GROUP = "org.python.pydev.debug.coverage";
	static final String PYTHON_UNITTEST_LAUNCH_GROUP = "org.python.pydev.debug.unittest";
	static final String ID_PYTHON_REGULAR_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.regularLaunchConfigurationType";
	static final String ID_PYTHON_COVERAGE_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.coverageLaunchConfigurationType";
	static final String ID_PYTHON_UNITTEST_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.unittestLaunchConfigurationType";
	static final String ID_JYTHON_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.jythonLaunchConfigurationType";
	static final String PROCESS_TYPE = "PYDEV.PYTHON";
	
// LaunchConfiguration properties
// ATTR_* are copied from IExternalToolConstants, replicated since I have no access to originals
	static final String ATTR_LOCATION = "org.eclipse.ui.externaltools" + ".ATTR_LOCATION";
	static final String ATTR_WORKING_DIRECTORY = "org.eclipse.ui.externaltools" + ".ATTR_WORKING_DIRECTORY";
	static final String ATTR_PROGRAM_ARGUMENTS = "org.eclipse.ui.externaltools" + ".ATTR_TOOL_ARGUMENTS";

	static final String ATTR_INTERPRETER = PLUGIN_ID + ".ATTR_INTERPRETER";
	static final String ATTR_PROJECT = PLUGIN_ID + ".ATTR_PROJECT";
	static final String ATTR_RESOURCE_TYPE = PLUGIN_ID + ".ATTR_RESOURCE_TYPE";
	
	
}

==> eclipse-pydev_1.2.0.orig.tar.gz: eclipse-pydev-1.2.0/org.python.pydev.debug/src/org/python/pydev/debug/core/Constants.java <==
/*
 * Author: atotic
 * Created: Aug 20, 2003
 * License: Common Public License v1.0
 */
package org.python.pydev.debug.core;

/**
 * all the public constants for pydev.debug
 */
public interface Constants {

	// Icons
	static final String MAIN_ICON = "icons/python.gif";
	
	// Plugin constants
	static final String PLUGIN_ID = "org.python.pydev.debug";
	static final String PYTHON_DEBUG_LAUNCH_GROUP = "org.python.pydev.debug.debug";
	static final String PYTHON_RUN_LAUNCH_GROUP = "org.python.pydev.debug.run";
	static final String PYTHON_COVERAGE_LAUNCH_GROUP = "org.python.pydev.debug.coverage";
	static final String PYTHON_UNITTEST_LAUNCH_GROUP = "org.python.pydev.debug.unittest";
	static final String ID_PYTHON_REGULAR_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.regularLaunchConfigurationType";
	static final String ID_PYTHON_COVERAGE_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.coverageLaunchConfigurationType";
	static final String ID_PYTHON_UNITTEST_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.unittestLaunchConfigurationType";
	static final String ID_JYTHON_LAUNCH_CONFIGURATION_TYPE = "org.python.pydev.debug.jythonLaunchConfigurationType";
	static final String PROCESS_TYPE = "PYDEV.PYTHON";
	
	static final String ATTR_VM_ARGUMENTS = "org.python.pydev.debug.vm.arguments";
	static final String JAVA_NATURE = "org.eclipse.jdt.core.javanature";
	
// LaunchConfiguration properties
// ATTR_* are copied from IExternalToolConstants, replicated since I have no access to originals
	static final String ATTR_LOCATION = "org.eclipse.ui.externaltools" + ".ATTR_LOCATION";
	static final String ATTR_WORKING_DIRECTORY = "org.eclipse.ui.externaltools" + ".ATTR_WORKING_DIRECTORY";
	static final String ATTR_PROGRAM_ARGUMENTS = "org.eclipse.ui.externaltools" + ".ATTR_TOOL_ARGUMENTS";

	static final String ATTR_INTERPRETER = PLUGIN_ID + ".ATTR_INTERPRETER";
	static final String ATTR_PROJECT = PLUGIN_ID + ".ATTR_PROJECT";
	static final String ATTR_RESOURCE_TYPE = PLUGIN_ID + ".ATTR_RESOURCE_TYPE";
	
	
}
